Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(22)

Unified Diff: chrome/browser/ui/webui/options/sync_setup_handler.cc

Issue 2279713002: Make PassphraseType a "enum class" instead of "enum". (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix java Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/options/sync_setup_handler.cc
diff --git a/chrome/browser/ui/webui/options/sync_setup_handler.cc b/chrome/browser/ui/webui/options/sync_setup_handler.cc
index 40fd0d44be3f3789335be2d54182c0b0ee2aa488..bd7197aeeb177f336e93295c199e0e9e82529169 100644
--- a/chrome/browser/ui/webui/options/sync_setup_handler.cc
+++ b/chrome/browser/ui/webui/options/sync_setup_handler.cc
@@ -893,9 +893,10 @@ void SyncSetupHandler::DisplayConfigureSync(bool passphrase_failed) {
args.SetBoolean("showPassphrase", service->IsPassphraseRequired());
// To distinguish between FROZEN_IMPLICIT_PASSPHRASE and CUSTOM_PASSPHRASE
// we only set usePassphrase for CUSTOM_PASSPHRASE.
args.SetBoolean("usePassphrase",
- service->GetPassphraseType() == syncer::CUSTOM_PASSPHRASE);
+ service->GetPassphraseType() ==
+ syncer::PassphraseType::CUSTOM_PASSPHRASE);
base::Time passphrase_time = service->GetExplicitPassphraseTime();
syncer::PassphraseType passphrase_type = service->GetPassphraseType();
if (!passphrase_time.is_null()) {
@@ -910,13 +911,13 @@ void SyncSetupHandler::DisplayConfigureSync(bool passphrase_failed) {
GetStringFUTF16(IDS_SYNC_ENTER_GOOGLE_PASSPHRASE_BODY_WITH_DATE,
passphrase_time_str));
switch (passphrase_type) {
- case syncer::FROZEN_IMPLICIT_PASSPHRASE:
+ case syncer::PassphraseType::FROZEN_IMPLICIT_PASSPHRASE:
args.SetString(
"fullEncryptionBody",
GetStringFUTF16(IDS_SYNC_FULL_ENCRYPTION_BODY_GOOGLE_WITH_DATE,
passphrase_time_str));
break;
- case syncer::CUSTOM_PASSPHRASE:
+ case syncer::PassphraseType::CUSTOM_PASSPHRASE:
args.SetString(
"fullEncryptionBody",
GetStringFUTF16(IDS_SYNC_FULL_ENCRYPTION_BODY_CUSTOM_WITH_DATE,
@@ -928,7 +929,7 @@ void SyncSetupHandler::DisplayConfigureSync(bool passphrase_failed) {
GetStringUTF16(IDS_SYNC_FULL_ENCRYPTION_BODY_CUSTOM));
break;
}
- } else if (passphrase_type == syncer::CUSTOM_PASSPHRASE) {
+ } else if (passphrase_type == syncer::PassphraseType::CUSTOM_PASSPHRASE) {
args.SetString(
"fullEncryptionBody",
GetStringUTF16(IDS_SYNC_FULL_ENCRYPTION_BODY_CUSTOM));
@@ -893,9 +893,10 @@ void SyncSetupHandler::DisplayConfigureSync(bool passphrase_failed) {
args.SetBoolean("showPassphrase", service->IsPassphraseRequired());
// To distinguish between FROZEN_IMPLICIT_PASSPHRASE and CUSTOM_PASSPHRASE
- // we only set usePassphrase for CUSTOM_PASSPHRASE.
+ // we only set usePassphrase for PassphraseType::CUSTOM_PASSPHRASE.
args.SetBoolean("usePassphrase",
« no previous file with comments | « chrome/browser/sync/profile_sync_service_android.cc ('k') | chrome/browser/ui/webui/options/sync_setup_handler_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698